@@ -8,6 +8,8 @@ public class      PerlActionListener
     String sender;
     String callbacks;
 
+    public PerlActionListener() throws InlineJavaException { }
+
     public PerlActionListener(String sender, String callbacks)
         throws InlineJavaException
     {
@@ -15,6 +17,9 @@ public class      PerlActionListener
         this.callbacks = callbacks;
     }
 
+    public void setSender   (String sender)    { this.sender    = sender; }
+    public void setCallbacks(String callbacks) { this.callbacks = callbacks; }
+
     public void actionPerformed(java.awt.event.ActionEvent event) {
         try {
             CallPerl(
